#!/usr/bin/env python3
# Copyright (C) 2025 Spearhead Systems SRL

from cmk.rulesets.v1.form_specs.validators import LengthInRange
from cmk.rulesets.v1.form_specs import Dictionary, DictElement, SingleChoice, SingleChoiceElement, List, String, DefaultValue
from cmk.rulesets.v1.rule_specs import SpecialAgent, Topic, Title, Help
from cmk.agent_based.v2 import State


def _formspec():
    return Dictionary(
        title=Title("Domains Nameservers"),
        elements={
            "domain_nameservers": DictElement(
                required=True,
                parameter_form=List(
                    title=Title("Domains to check"),
                    help_text=Help("List of domain names to check"),
                    editable_order=False,
                    custom_validate=(LengthInRange(min_value=1),),
                    element_template=Dictionary(
                        elements={
                            "domains": DictElement(
                                required=True,
                                parameter_form=List(
                                    title=Title("Domain names"),
                                    help_text=Help("List of domain names the below nameservers apply to"),
                                    custom_validate=(LengthInRange(min_value=1),),
                                    element_template=String(
                                        custom_validate=(LengthInRange(min_value=3),),
                                    ),
                                ),
                            ),
                            "nameservers": DictElement(
                                required=True,
                                parameter_form=List(
                                    title=Title("Nameservers"),
                                    help_text=Help("List of nameservers that the above domain names should have"),
                                    custom_validate=(LengthInRange(min_value=1),),
                                    element_template=String(
                                        custom_validate=(LengthInRange(min_value=3),),
                                    ),
                                ),
                            ),
                        }
                    )
                ),
            ),
            "alert_level": DictElement(
                required=True,
                parameter_form=SingleChoice(
                    title=Title("Alert level used on mismatch"),
                    help_text=Help("Alert level used when there is a mismatch in domain name servers for a domain"),
                    prefill=DefaultValue(State.WARN.name),
                    elements=[
                        SingleChoiceElement(name=State.CRIT.name, title=Title(State.CRIT.name)),
                        SingleChoiceElement(name=State.WARN.name, title=Title(State.WARN.name)),
                        SingleChoiceElement(name=State.OK.name,   title=Title(State.OK.name)),
                    ],
                ),
            ),
        },
    )

rule_spec_agent_config_domains_nameservers = SpecialAgent(
    topic=Topic.NETWORKING,
    name="domains_nameservers",
    title=Title("Domains Nameservers"),
    parameter_form=_formspec,
)
