#!/usr/bin/env python3
# Copyright (C) 2025 Spearhead Systems SRL

from cmk.server_side_calls.v1 import noop_parser, SpecialAgentConfig, SpecialAgentCommand


# Although the API makes it seem like we can yield several
# SpecialAgentCommands, the use of a table for _elems in
# lib/python3/cmk/base/sources/_builder.py (at least in 2.3.0p31) means that
# we can only emit one SpecialAgentCommands. This CheckMK bug means that
# SpecialAgentCommands() will be forgotten.
#
# Alas, that means we need to pack everything into a single command invocation.
def _agent_arguments(params, host_config):
    args = []

    alert_level = params["alert_level"]

    for ele in params["domain_nameservers"]:
        domains     = ele["domains"]
        nameservers = ele["nameservers"]
        
        args.append("--domains=" + ",".join(domains))
        args.append("--nameservers=" + ",".join(nameservers))
        args.append("--alert=" + alert_level)

    yield SpecialAgentCommand(command_arguments=args)


special_agent_domains_nameservers = SpecialAgentConfig(
    name="domains_nameservers",
    parameter_parser=noop_parser,
    commands_function=_agent_arguments,
)
