#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2020             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# This file is part of Check_MK.
# The official homepage is at http://mathias-kettner.de/check_mk.
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

#example output
#<<<hitachivsp_backup_modules:sep(9)>>>
#location	status	bat_location	bat_status	bat_life
#BKMF-10	Normal
#BKMF-11	Normal	BAT-B11	Normal	90
#BKMF-12	Normal	BAT-B12	Normal	90
#BKMF-13	Normal	BAT-B13	Normal	90
#BKMF-20	Normal
#BKMF-21	Normal	BAT-B21	Normal	90
#BKMF-22	Normal	BAT-B22	Normal	90
#BKMF-23	Normal	BAT-B23	Normal	90


from cmk.agent_based.v2 import Service, Result, State, CheckPlugin, Metric


def discover_hitachivsp_backup_modules(section):
    for line in section:
        if "location" not in line:
            yield Service(item=line[0])


def check_hitachivsp_backup_modules(item, params, section):
    for line in section:
        if item == line[0]:
            status = line[1]

            if status == "Normal":
                state   = State.OK
                summary = "Backup Module status is Normal"
            elif status == "Warning":
                state   = State.WARN
                summary = "Backup Module status is Warning"
            elif status == "Blocked":
                state   = State.CRIT
                summary = "Backup Module status is Blocked"
            elif status == "Failed":
                state   = State.CRIT
                summary = "Backup Module status is Failed"

            yield Result(state=state, summary=summary)

            if len(line) > 2:
                battery_status, battery_percent = line[3:5]

                yield Metric(name="battery_percent", value=int(battery_percent))

                if battery_status == "Normal":
                    b_state   = State.OK
                    b_summary = "Battery status is Normal"
                elif battery_status == "Warning":
                    b_state   = State.WARN
                    b_summary = "Battery status is Warning"
                elif battery_status == "Blocked":
                    b_state   = State.CRIT
                    b_summary = "Battery status is Blocked"
                elif battery_status == "Failed":
                    b_state   = State.CRIT
                    b_summary = "Battery status is Failed"

                yield Result(state=b_state, summary=b_summary)


check_plugin_hitachivsp_backup_modules = CheckPlugin(
    name="hitachivsp_backup_modules",
    service_name="Backup Module %s",
    discovery_function=discover_hitachivsp_backup_modules,
    check_function=check_hitachivsp_backup_modules,
    check_default_parameters={},
)
