#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2020             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# This file is part of Check_MK.
# The official homepage is at http://mathias-kettner.de/check_mk.
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

#example output
#<<<hitachivsp_channel_board:sep(9)>>>
#location	status	type
#CHB-1A	Normal	32G Ready 4Port FC
#CHB-1B	Normal	32G Ready 4Port FC
#CHB-2A	Normal	32G Ready 4Port FC
#CHB-2B	Normal	32G Ready 4Port FC


from cmk.agent_based.v2 import Service, Result, State, CheckPlugin


def discover_hitachivsp_cache_flash_memories(section):
    for line in section:
        if "location" not in line:
            yield Service(item=line[0])


def check_hitachivsp_cache_flash_memories(item, params, section):
    for line in section:
        if item == line[0]:
            status = line[1]

            if status == "Normal":
                state   = State.OK
                summary = "Cache memory status is Normal"
            if status == "Warning":
                state   = State.WARN
                summary = "Cache memory status is Warning"
            elif status == "Blocked":
                state   = State.CRIT
                summary = "Cache memory status is Blocked"
            elif status == "Failed":
                state   = State.CRIT
                summary = "Cache memory status is Failed"

            yield Result(state=state, summary=summary)


check_plugin_cache_flash_memories = CheckPlugin(
    name="hitachivsp_cache_flash_memories",
    service_name="Cache Flash Memory %s",
    discovery_function=discover_hitachivsp_cache_flash_memories,
    check_function=check_hitachivsp_cache_flash_memories,
    check_default_parameters={},
)
