#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2020             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# This file is part of Check_MK.
# The official homepage is at http://mathias-kettner.de/check_mk.
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

#example output
#<<<hitachivsp_ctls:sep(9)>>>
#location	status	temperature	temperatureStatus	charge
#CTL1	Normal	23	Normal	100
#CTL2	Normal	23	Normal	100


from cmk.agent_based.v2 import Service, Result, State, CheckPlugin, Metric


def discover_hitachivsp_ctls(section):
    for line in section:
        if "location" not in line:
            yield Service(item=line[0])


def check_hitachivsp_ctls(item, params, section):
    for line in section:
        if item == line[0]:
            status, temperature, temperature_status, charge = line[1:5]

            yield Metric("temperature", int(temperature))
            yield Metric("charge",      int(charge))

            if status == "Normal":
                state   = State.OK
                summary = "Controller status is Normal"
            elif status == "Warning":
                state   = State.WARN
                summary = "Controller status is Warning"
            elif status == "Blocked":
                state   = State.CRIT
                summary = "Controller status is Blocked"
            elif status == "Failed":
                state   = State.CRIT
                summary = "Controller status is Failed"

            yield Result(state=state, summary=summary)

            if temperature_status == "Normal":
                t_state   = State.OK
                t_summary = f"Temperature Status is Normal: {temperature}"
            if temperature_status == "Warning":
                t_state   = State.WARN
                t_summary = f"Temperature Status is Warning: {temperature}"
            elif temperature_status == "Failed":
                t_state   = State.CRIT
                t_summary = f"Temperature Status is Failed: %{temperature}"

            yield Result(state=t_state, summary=t_summary)


check_plugin_hitachivsp_ctls = CheckPlugin(
    name="hitachivsp_ctls",
    service_name="CTLS %s",
    discovery_function=discover_hitachivsp_ctls,
    check_function=check_hitachivsp_ctls,
    check_default_parameters={},
)
