#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2020             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# This file is part of Check_MK.
# The official homepage is at http://mathias-kettner.de/check_mk.
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

#example output
#<<<hitachivsp_drive_boxes_encs:sep(9)>>>
#drivebox_location	enc_location	enc_status
#DB-00	ENC00-1	Normal
#DB-00	ENC00-2	Normal
#DB-01	ENC01-1	Normal
#DB-01	ENC01-2	Normal
#DB-02	ENC02-1	Normal
#DB-02	ENC02-2	Normal
#DB-03	ENC03-1	Normal
#DB-03	ENC03-2	Normal


from cmk.agent_based.v2 import Service, Result, State, CheckPlugin


def discover_hitachivsp_drive_boxes_encs(section):
    for line in section:
        if "drivebox_location" not in line:
            yield Service(item=line[1])


def check_hitachivsp_drive_boxes_encs(item, params, section):
    for line in section:
        if item == line[1]:
            status = line[2]

            if status == "Normal":
                state   = State.OK
                summary = "Drive Enclosure status is Normal"
            elif status == "Warning":
                state   = State.WARN
                summary = "Drive Enclosure status is Warning"
            elif status == "Blocked":
                state   = State.CRIT
                summary = "Drive Enclosure status is Blocked"
            elif status == "Failed":
                state = State.CRIT
                summary = "Drive Enclosure status is Failed"

            yield Result(state=state, summary=summary)


check_plugin_hitachivsp_drive_boxes_encs = CheckPlugin(
    name="hitachivsp_drive_boxes_encs",
    service_name="Drive box enclosure %s",
    discovery_function=discover_hitachivsp_drive_boxes_encs,
    check_function=check_hitachivsp_drive_boxes_encs,
    check_default_parameters={},
)
