#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2020             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# This file is part of Check_MK.
# The official homepage is at http://mathias-kettner.de/check_mk.
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

#example output
#<<<hitachivsp_parity_groups:sep(9)>>>
#parityGroupId	numOfLdevs	usedCapacityRate	clprId	availableVolumeCapacity	totalCapacity	physicalCapacity
#1-1	26	44	0	87245	157286	39321
#1-2	51	93	0	10448	157286	39321
#1-3	25	42	0	90317	157286	39321
#1-4	52	95	0	7376	157286	39321
#1-5	54	99	0	1232	157286	39321
#1-6	25	42	0	90317	157286	39321


from cmk.agent_based.v2 import Service, Result, State, CheckPlugin, Metric


def discover_hitachivsp_parity_groups(section):
    for line in section:
        if "parityGroupId" not in line:
            yield Service(item=line[0])


def check_hitachivsp_parity_groups(item, params, section):
    for line in section:
        if item == line[0]:
            rate, _, avail, total = line[2:6]

            yield Metric(name="UsedCapacityRate",        value=int(rate))
            yield Metric(name="AvailableVolumeCapacity", value=int(avail))
            yield Metric(name="TotalCapacity",           value=int(total))

            yield Result(
                state=State.OK,
                summary=f"UsedCapacityRate: {rate}; AvailableVolumeCapacity(GB): {avail}; TotalCapacity(GB): {total}"
            )


check_plugin_hitachivsp_parity_groups = CheckPlugin(
    name="hitachivsp_parity_groups",
    service_name="Parity Group %s",
    discovery_function=discover_hitachivsp_parity_groups,
    check_function=check_hitachivsp_parity_groups,
    check_default_parameters={},
)
