#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2020             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# This file is part of Check_MK.
# The official homepage is at http://mathias-kettner.de/check_mk.
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

#example output
#<<<hitachivsp_pools:sep(9)>>>
#poolID	poolType	poolName	totalPhysicalCapacity	totalPoolCapacity	availableVolumeCapacity	usedCapacityRate	poolStatus
#0	RT	RAID6_HDT_01	397630296	397630296	208964826	47	POLN
#1	HTI	THIN_IMAGE_POOL	46453344	46453344	46453344	0	POLN


from cmk.agent_based.v2 import Service, Result, State, CheckPlugin, Metric


def discover_hitachivsp_pools(section):
    for line in section:
        if "poolID" not in line:
            yield Service(item=line[0])


def check_hitachivsp_pools(item, params, section):
    for line in section:
        if item == line[0]:
            name, phys_cap, pool_cap, avail, rate, status = line[2:8]

            yield Metric(name="TotalPhysicalCapacity",   value=int(phys_cap))
            yield Metric(name="TotalPoolCapacity",       value=int(pool_cap))
            yield Metric(name="AvailableVolumeCapacity", value=int(avail))
            yield Metric(name="UsedCapacityRate",        value=int(rate))

            if status == "POLN":
                state   = State.OK
                summary = f"Pool {name} is Normal"
            elif status == "POLE":
                state   = State.CRIT
                summary = f"Pool {name} is suspended in failure status"
            elif status == "POLF":
                state   = State.CRIT
                summary = f"Pool {name} is Full"
            elif status == "POLS":
                state   = State.CRIT
                summary = f"Pool {name} is Suspended"

            yield Result(state=state, summary=summary)


check_plugin_hitachivsp_pools = CheckPlugin(
    name="hitachivsp_pools",
    service_name="Pool %s",
    discovery_function=discover_hitachivsp_pools,
    check_function=check_hitachivsp_pools,
    check_default_parameters={},
)
