#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2020             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# This file is part of Check_MK.
# The official homepage is at http://mathias-kettner.de/check_mk.
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

#example output
#<<<hitachivsp_sfps:sep(9)>>>
#portId	status	type	speed	portCondition
#1A	Normal	Short Wave	16 Gbps	Available (Connected)
#3A	Normal	Short Wave	16 Gbps	Available (Connected)
#5A	Normal	Short Wave	16 Gbps	Available (Connected)
#7A	Normal	Short Wave	16 Gbps	Available (Connected)
#1B	Normal	Short Wave	16 Gbps	Available (Connected)
#3B	Normal	Short Wave	16 Gbps	Available (Connected)
#5B	Normal	Short Wave	16 Gbps	Available (Connected)
#7B	Normal	Short Wave	16 Gbps	Available (Connected)
#2A	Normal	Short Wave	16 Gbps	Available (Connected)
#4A	Normal	Short Wave	16 Gbps	Available (Connected)
#6A	Normal	Short Wave	16 Gbps	Available (Connected)
#8A	Normal	Short Wave	16 Gbps	Available (Connected)
#2B	Normal	Short Wave	16 Gbps	Available (Connected)
#4B	Normal	Short Wave	16 Gbps	Available (Connected)
#6B	Normal	Short Wave	16 Gbps	Available (Connected)
#8B	Normal	Short Wave	16 Gbps	Available (Connected)


from cmk.agent_based.v2 import Service, Result, State, CheckPlugin


def discover_hitachivsp_sfps(section):
    for line in section:
        if "portId" not in line:
            yield Service(item=line[0])


def check_hitachivsp_sfps(item, params, section):
    for line in section:
        if item == line[0]:
            status = line[1]
            port_condition = line[4]

            if status == "Normal":
                state   = State.OK
                summary = "SFP status is Normal"
            elif status == "Warning":
                state   = State.WARN
                summary = "SFP status is Warning"
            elif status == "Not fix":
                state   = State.CRIT
                summary ="SFP status is Not fix"

            yield Result(state=state, summary=summary)

            if port_condition == "Available (Connected)":
                p_state   = State.OK
                p_summary = "SFP is Connected"
            elif port_condition == "Available (Not Connected)":
                p_state   = State.WARN
                p_summary = "SFP is not Connected"
            elif port_condition == "Not Available":
                p_state   = State.CRIT
                p_summary = "SFP is not available"

            yield Result(state=p_state, summary=p_summary)


check_plugin_hitachivsp_sfps = CheckPlugin(
    name="hitachivsp_sfps",
    service_name="SFP Port %s",
    discovery_function=discover_hitachivsp_sfps,
    check_function=check_hitachivsp_sfps,
    check_default_parameters={},
)
