#!/usr/bin/env python3

from cmk.rulesets.v1.form_specs.validators import LengthInRange
from cmk.rulesets.v1.form_specs import Dictionary, DictElement, String, Password, BooleanChoice, DefaultValue
from cmk.rulesets.v1.rule_specs import SpecialAgent, Topic, Title, Help


def _formspec():
    return Dictionary(
        title=Title("Check HITACHI VSP Storages"),
        help_text=Help("This rule set selects the special agent for Hitachi VSP "
               "Storages instead of the normal Check_MK agent and allows "
               "monitoring via Web API. "),
        elements={
            "user": DictElement(
                required=True,
                parameter_form=String(
                    title=Title("Username"),
                    custom_validate=(LengthInRange(min_value=1),),
                ),
            ),
            "password": DictElement(
                required=True,
                parameter_form=Password(
                    title=Title("Password"),
                    custom_validate=(LengthInRange(min_value=1),),
                )
            ),
            "cert": DictElement(
                required=True,
                parameter_form=BooleanChoice(
                    title=Title("SSL certificate verification"),
                    prefill=DefaultValue(True),
                )
            ),
        },
    )


rule_spec_agent_config_hitachivsp = SpecialAgent(
    topic=Topic.STORAGE,
    name="hitachivsp",
    title=Title("Hitachi VSP"),
    parameter_form=_formspec,
)
